@@ -6,10 +6,9 @@ import zmq
 
 def main():
     ctx = zmq.Context()
-    in_socket = ctx.socket(zmq.SUB)
-    in_socket.setsockopt(zmq.SUBSCRIBE, '')
+    in_socket = ctx.socket(zmq.PULL)
     in_socket.connect('tcp://localhost:9241')
-    out_socket = ctx.socket(zmq.PUB)
+    out_socket = ctx.socket(zmq.PUSH)
     out_socket.connect('tcp://localhost:9242')
 
     print 'Listening for messages'
@@ -27,6 +26,9 @@ def main():
                 out_socket.send_multipart(['message',
                                            session_id,
                                            'The time now is: ' + str(datetime.datetime.now())])
+                out_socket.send_multipart(['disconnect',
+                                           session_id,
+                                           ''])
     except KeyboardInterrupt:
         pass
 
