@@ -1,6 +1,11 @@
+from __future__ import absolute_import
+
 import logging
 import argparse
 import time, signal
+import os.path as p
+
+from sockjsproxy import VERSION
 
 import zmq
 from zmq.eventloop import zmqstream
@@ -37,8 +42,7 @@ class BackendConnection(object):
         if command == 'message':
             self.frontend.send(session_id, message)
         elif command == 'disconnect':
-            # TODO: Drop the connection
-            pass
+            self.frontend.close(session_id)
         else:
             log.warn("Invalid command %s", command)
 
@@ -120,10 +124,20 @@ class FrontendConnection(object):
 
         connection.send(message)
 
+    def close(self, session_id):
+        connection = self.sessions.get(session_id)
+        if not connection:
+            log.warn('Could not close session %s: '
+                     'Connection not found.', session_id)
+            return
+
+        connection.close()
+
 
 class SockJSProxy(object):
     def collect_args(self):
         parser = argparse.ArgumentParser(description="Proxy messages between sock.js and a 0MQ socket")
+        parser.add_argument('--version', action='version', version="%(prog)s " + VERSION)
         parser.add_argument('--address', '-a', type=str,
                             help="The 0MQ address to listen to. Defaults to * (meaning - everything)",
                             default='*')
@@ -146,7 +160,7 @@ class SockJSProxy(object):
 
         parser.add_argument('--samples', type=str,
                             help='Serve samples under SAMPLES path')
-        parser.add_argument('--verbose', action='store_true', default=False,
+        parser.add_argument('--verbose', '-v', action='store_true', default=False,
                             help='Make the server output more information - useful for debugging')
 
         args = parser.parse_args()
@@ -154,6 +168,11 @@ class SockJSProxy(object):
         if bool(args.static_path) != bool(args.static_url):
             parser.error("You should specify both --static-path and --static-url to have static files served.")
 
+        if args.static_path and (not p.exists(args.static_path) or
+                                 not p.isdir(args.static_path)):
+            parser.error("Static directory %s does not "
+                         "exists or not directory" % args.static_path)
+
         return args
 
     def init_logging(self, verbose):
@@ -170,11 +189,10 @@ class SockJSProxy(object):
         log.info("Pulling outgoing messages from: %s", out_address)
 
         ctx = zmq.Context()
-        in_socket = ctx.socket(zmq.PUB)
+        in_socket = ctx.socket(zmq.PUSH)
         in_socket.bind(in_address)
-        out_socket = ctx.socket(zmq.SUB)
+        out_socket = ctx.socket(zmq.PULL)
         out_socket.bind(out_address)
-        out_socket.setsockopt(zmq.SUBSCRIBE, '')
 
         io_loop = ioloop.IOLoop.instance() # ZMQ loop
 
@@ -191,7 +209,6 @@ class SockJSProxy(object):
 
         if args.samples:
             sample_url = '/' + args.samples.strip('/')
-            import os.path as p
             sample_path = p.join(p.abspath(p.dirname(__file__)), 'samples')
             log.info("Serving samples content at %s", sample_url)
             routes += [(r"%s/?(.*)" % sample_url, web.StaticFileHandler,
